@@ -21,6 +21,7 @@ from tricc_oo.models.tricc import (
     TriccNodeSelectOption,
     TriccNodeInputModel,
     TriccNodeBaseModel,
+    TriccNodeSelect,
     TriccNodeDisplayModel,
 )
 
@@ -69,6 +70,9 @@ class OpenMRSStrategy(BaseOutPutStrategy):
         self.current_segment = None
         self.current_activity = None
         self.concept_map = {}
+        self.calculated_fields = []  # Store calculated fields to add to first section of each page
+        self.calculated_fields_added = set()  # Track which pages have had calculated fields added
+        self.inject_version()
 
     def get_export_name(self, r):
         if isinstance(r, TriccNodeSelectOption):
@@ -146,6 +150,9 @@ class OpenMRSStrategy(BaseOutPutStrategy):
         logger.info("generate the export format")
         self.process_export(self.project.start_pages, pages=self.project.pages)
 
+        logger.info("create calculation page")
+        self.create_calculation_page()
+
         logger.info("print the export")
         self.export(self.project.start_pages, version=version)
 
@@ -160,7 +167,7 @@ class OpenMRSStrategy(BaseOutPutStrategy):
             'select_multiple': 'multiCheckbox',
             'select_yesno': 'select',
             'not_available': 'checkbox',
-            'note': 'text'
+            'note': 'markdown'
         }
 
         # if issubclass(node.__class__, TriccNodeSelectYesNo):
@@ -250,7 +257,9 @@ class OpenMRSStrategy(BaseOutPutStrategy):
                         }
                     }
                 }
-                return question
+                # Collect calculated fields to add to first section of each page
+                self.calculated_fields.append(question)
+                return None  # Don't return the question, it will be added to first section
         return None
 
     def generate_calculate(self, node, processed_nodes, **kwargs):
@@ -400,6 +409,8 @@ class OpenMRSStrategy(BaseOutPutStrategy):
             return f"'{option}'"
         elif issubclass(r.__class__, TriccNodeInputModel):
             return self.get_export_name(r)
+        elif issubclass(r.__class__, TriccNodeSelect):
+            return "(" + self.get_export_name(r) + " ?? [])"       
         elif issubclass(r.__class__, TriccNodeBaseModel):
             return self.get_export_name(r)
         else:
@@ -439,7 +450,7 @@ class OpenMRSStrategy(BaseOutPutStrategy):
         if len(ref_expressions) == 1:
             return ref_expressions[0]
         if len(ref_expressions) > 1:
-            return " || ".join(ref_expressions)
+            return "(" + " || ".join(ref_expressions) + ")"
         else:
             return "true"
 
@@ -447,7 +458,7 @@ class OpenMRSStrategy(BaseOutPutStrategy):
         return f"!({ref_expressions[0]})"
 
     def tricc_operation_plus(self, ref_expressions):
-        return " + ".join(ref_expressions)
+        return "(" + " + ".join(ref_expressions) +")" 
 
     def tricc_operation_minus(self, ref_expressions):
         if len(ref_expressions) > 1:
@@ -472,7 +483,7 @@ class OpenMRSStrategy(BaseOutPutStrategy):
         return f"({ref_expressions[0]}.includes({ref_expressions[1]}))"
 
     def tricc_operation_count(self, ref_expressions):
-        return f"({ref_expressions[0]}.length)"
+        return f"{ref_expressions[0]}.length"
 
     def tricc_operation_multiplied(self, ref_expressions):
         return "*".join(ref_expressions)
@@ -638,6 +649,7 @@ class OpenMRSStrategy(BaseOutPutStrategy):
             "label": section_label,
             "questions": []
         })
+
         if group_node.relevance:
             relevance_str = self.convert_expression_to_string(not_clean(group_node.relevance))
             if relevance_str and relevance_str != 'false':
@@ -645,3 +657,38 @@ class OpenMRSStrategy(BaseOutPutStrategy):
                     "hideWhenExpression": f"{relevance_str}"
                 }
         logger.debug(f"Started section: {section_label}")
+
+    def create_calculation_page(self):
+        """Create a dedicated page for all calculated fields"""
+        if self.calculated_fields:
+            self.clean_sections()
+            self.clean_pages()
+            page = {
+                "label": "Calculations",
+                "sections": [
+                    {
+                        "label": "Calculations",
+                        "questions": self.calculated_fields
+                    }
+                ]
+            }
+            self.form_data["pages"].append(page)
+            logger.debug("Created calculation page")
+
+    def inject_version(self):
+        # Add hidden version field using version() function
+        question = {
+            "id": "version",
+            "type": "control",
+            "label": "",
+            "hide": {
+                "hideWhenExpression": "true"
+            },
+            "questionOptions": {
+                "calculate": {
+                    "calculateExpression": "version()"
+                }
+            }
+        }
+        # Collect calculated fields to add to first section of each page
+        self.calculated_fields.append(question)
