@@ -131,7 +131,7 @@ class XLSFormStrategy(BaseOutPutStrategy):
         return generate_xls_form_export(self, node, **kwargs)
 
     def inject_version(self):
-        # Add hidden version field using ODK's jr:version()
+        # Add hidden version field using ODK's version()
         empty = langs.get_trads("", force_dict=True)
         self.df_survey.loc[len(self.df_survey)] = [
             "hidden",
@@ -148,7 +148,7 @@ class XLSFormStrategy(BaseOutPutStrategy):
             "",  # required
             *list(empty.values()),  # required_message
             "",  # read only
-            "jr:version()",  # calculation
+            "version()",  # calculation
             "",  # trigger
             "",  # repeat_count
             "",  # image
@@ -399,7 +399,7 @@ class XLSFormStrategy(BaseOutPutStrategy):
         # build lower level
         if hasattr(self, f"tricc_operation_{operation.operator}"):
             callable = getattr(self, f"tricc_operation_{operation.operator}")
-            return callable(ref_expressions)
+            return callable(list(map(str, ref_expressions)))
         else:
             raise NotImplementedError(
                 f"This type of opreation '{operation.operator}' is not supported in this strategy"
@@ -460,9 +460,9 @@ class XLSFormStrategy(BaseOutPutStrategy):
             return "1"
 
     def tricc_operation_native(self, ref_expressions):
-    
+
         if len(ref_expressions) > 0:
-            if ref_expressions[0].startswith(("'","`",)):
+            if ref_expressions[0].startswith(("'", "`",)):
                 ref_expressions[0] = ref_expressions[0][1:-1]
             if ref_expressions[0] == "GetChoiceName":
                 return f"""jr:choice-name({
@@ -723,19 +723,8 @@ class XLSFormStrategy(BaseOutPutStrategy):
         elif isinstance(r, TriccReference):
             logger.warning(f"reference `{r.value}` still used in a calculate")
             return f"${{{get_export_name(r.value)}}}"
-        elif isinstance(r, TriccStatic):
+        elif isinstance(r, (TriccStatic, str, int, float)):
             return get_export_name(r)
-        elif isinstance(r, str):
-            if r == TRICC_TRUE_VALUE:
-                return BOOLEAN_MAP[str(TRICC_TRUE_VALUE)]
-            elif r == TRICC_FALSE_VALUE:
-                return BOOLEAN_MAP[str(TRICC_FALSE_VALUE)]
-            elif isinstance(r, str):
-                return f"'{r}'"
-            else:
-                return str(r)
-        elif isinstance(r, (int, float)):
-            return str(r)
         elif isinstance(r, TriccNodeSelectOption):
             logger.debug(f"select option {r.get_name()} from {r.select.get_name()} was used as a reference")
             return get_export_name(r)
